pub struct EntryMut<'a, T: Ord, V> { /* private fields */ }Expand description
A find_mut query on the interval tree does not directly return references to the nodes in the tree, but
wraps the fields interval and data in an EntryMut. Only the data part can be mutably accessed
using the data method
Implementations